"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
from ..... import neptune_pb
import typing
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RequestId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str

    def __init__(self, *, value: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['value', b'value']) -> None:
        ...
global___RequestId = RequestId

@typing.final
class RequestIdList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IDS_FIELD_NUMBER: builtins.int

    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RequestId]:
        ...

    def __init__(self, *, ids: collections.abc.Iterable[global___RequestId] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['ids', b'ids']) -> None:
        ...
global___RequestIdList = RequestIdList

@typing.final
class BulkRequestStatus(google.protobuf.message.Message):
    """Maps a list of request identifiers to their respective statuses.
    The backend API guarantees that the number of returned fields is equal
    to the number of requested IDs, and the order is the same as requested.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUSES_FIELD_NUMBER: builtins.int

    @property
    def statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[neptune_pb.ingest.v1.pub.request_status_pb2.RequestStatus]:
        ...

    def __init__(self, *, statuses: collections.abc.Iterable[neptune_pb.ingest.v1.pub.request_status_pb2.RequestStatus] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['statuses', b'statuses']) -> None:
        ...
global___BulkRequestStatus = BulkRequestStatus

@typing.final
class SubmitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUEST_ID_FIELD_NUMBER: builtins.int
    REQUEST_IDS_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    'wire-compatibility with RequestId. Will be deprecated'

    @property
    def request_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        ...

    def __init__(self, *, request_id: builtins.str=..., request_ids: collections.abc.Iterable[builtins.str] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['request_id', b'request_id', 'request_ids', b'request_ids']) -> None:
        ...
global___SubmitResponse = SubmitResponse

@typing.final
class StatusCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    project: builtins.str

    @property
    def request_id(self) -> global___RequestId:
        ...

    def __init__(self, *, project: builtins.str=..., request_id: global___RequestId | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['request_id', b'request_id']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['project', b'project', 'request_id', b'request_id']) -> None:
        ...
global___StatusCheck = StatusCheck

@typing.final
class BulkStatusCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    project: builtins.str

    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RequestId]:
        """wire-compatibility with RequestIdList"""

    def __init__(self, *, project: builtins.str=..., ids: collections.abc.Iterable[global___RequestId] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['ids', b'ids', 'project', b'project']) -> None:
        ...
global___BulkStatusCheck = BulkStatusCheck

@typing.final
class BulkCheckDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    NEXT_CURSOR_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    project: builtins.str
    next_cursor: builtins.str
    limit: builtins.int

    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RequestId]:
        ...

    def __init__(self, *, project: builtins.str=..., ids: collections.abc.Iterable[global___RequestId] | None=..., next_cursor: builtins.str | None=..., limit: builtins.int | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_limit', b'_limit', '_next_cursor', b'_next_cursor', 'limit', b'limit', 'next_cursor', b'next_cursor']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_limit', b'_limit', '_next_cursor', b'_next_cursor', 'ids', b'ids', 'limit', b'limit', 'next_cursor', b'next_cursor', 'project', b'project']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_limit', b'_limit']) -> typing.Literal['limit'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_next_cursor', b'_next_cursor']) -> typing.Literal['next_cursor'] | None:
        ...
global___BulkCheckDetail = BulkCheckDetail

@typing.final
class IngestResultDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUEST_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    INGEST_CODE_FIELD_NUMBER: builtins.int
    ERROR_DETAIL_FIELD_NUMBER: builtins.int
    path: builtins.str
    ingest_code: neptune_pb.ingest.v1.ingest_pb2.IngestCode.ValueType
    error_detail: builtins.str

    @property
    def request_id(self) -> global___RequestId:
        ...

    def __init__(self, *, request_id: global___RequestId | None=..., path: builtins.str=..., ingest_code: neptune_pb.ingest.v1.ingest_pb2.IngestCode.ValueType=..., error_detail: builtins.str=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['request_id', b'request_id']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['error_detail', b'error_detail', 'ingest_code', b'ingest_code', 'path', b'path', 'request_id', b'request_id']) -> None:
        ...
global___IngestResultDetail = IngestResultDetail

@typing.final
class BulkIngestResultDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DETAILS_FIELD_NUMBER: builtins.int
    NEXT_CURSOR_FIELD_NUMBER: builtins.int
    next_cursor: builtins.str

    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IngestResultDetail]:
        ...

    def __init__(self, *, details: collections.abc.Iterable[global___IngestResultDetail] | None=..., next_cursor: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['details', b'details', 'next_cursor', b'next_cursor']) -> None:
        ...
global___BulkIngestResultDetail = BulkIngestResultDetail


#
# Copyright (c) 2025, Neptune Labs Sp. z o.o.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from http import HTTPStatus
from io import BytesIO
from typing import (
    Any,
    Dict,
    Optional,
    Union,
    cast,
)

import httpx

from ... import errors
from ...client import (
    AuthenticatedClient,
    Client,
)
from ...models.query_attributes_body_dto import QueryAttributesBodyDTO
from ...types import (
    UNSET,
    File,
    Response,
    Unset,
)


def _get_kwargs(
    *,
    body: QueryAttributesBodyDTO,
    project_identifier: str,
    x_neptune_client_metadata: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}
    if not isinstance(x_neptune_client_metadata, Unset):
        headers["X-Neptune-Client-Metadata"] = x_neptune_client_metadata

    params: Dict[str, Any] = {}

    params["projectIdentifier"] = project_identifier

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/api/leaderboard/v1/proto/leaderboard/attributes/query",
        "params": params,
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, File]]:
    try:
        if response.status_code == HTTPStatus.OK:
            response_200 = File(payload=BytesIO(response.content))

            return response_200
        if response.status_code == HTTPStatus.BAD_REQUEST:
            response_400 = cast(Any, None)
            return response_400
        if response.status_code == HTTPStatus.UNAUTHORIZED:
            response_401 = cast(Any, None)
            return response_401
        if response.status_code == HTTPStatus.FORBIDDEN:
            response_403 = cast(Any, None)
            return response_403
        if response.status_code == HTTPStatus.NOT_FOUND:
            response_404 = cast(Any, None)
            return response_404
        if response.status_code == HTTPStatus.REQUEST_TIMEOUT:
            response_408 = cast(Any, None)
            return response_408
        if response.status_code == HTTPStatus.CONFLICT:
            response_409 = cast(Any, None)
            return response_409
        if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
            response_422 = cast(Any, None)
            return response_422
        if response.status_code == HTTPStatus.TOO_MANY_REQUESTS:
            response_429 = cast(Any, None)
            return response_429
    except Exception as e:
        raise errors.UnableToParseResponse(e, response) from e

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, File]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: QueryAttributesBodyDTO,
    project_identifier: str,
    x_neptune_client_metadata: Union[Unset, str] = UNSET,
) -> Response[Union[Any, File]]:
    """Queries attributes

    Args:
        project_identifier (str):
        x_neptune_client_metadata (Union[Unset, str]):
        body (QueryAttributesBodyDTO):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, File]]
    """

    kwargs = _get_kwargs(
        body=body,
        project_identifier=project_identifier,
        x_neptune_client_metadata=x_neptune_client_metadata,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: QueryAttributesBodyDTO,
    project_identifier: str,
    x_neptune_client_metadata: Union[Unset, str] = UNSET,
) -> Optional[Union[Any, File]]:
    """Queries attributes

    Args:
        project_identifier (str):
        x_neptune_client_metadata (Union[Unset, str]):
        body (QueryAttributesBodyDTO):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, File]
    """

    return sync_detailed(
        client=client,
        body=body,
        project_identifier=project_identifier,
        x_neptune_client_metadata=x_neptune_client_metadata,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: QueryAttributesBodyDTO,
    project_identifier: str,
    x_neptune_client_metadata: Union[Unset, str] = UNSET,
) -> Response[Union[Any, File]]:
    """Queries attributes

    Args:
        project_identifier (str):
        x_neptune_client_metadata (Union[Unset, str]):
        body (QueryAttributesBodyDTO):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, File]]
    """

    kwargs = _get_kwargs(
        body=body,
        project_identifier=project_identifier,
        x_neptune_client_metadata=x_neptune_client_metadata,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: QueryAttributesBodyDTO,
    project_identifier: str,
    x_neptune_client_metadata: Union[Unset, str] = UNSET,
) -> Optional[Union[Any, File]]:
    """Queries attributes

    Args:
        project_identifier (str):
        x_neptune_client_metadata (Union[Unset, str]):
        body (QueryAttributesBodyDTO):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, File]
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
            project_identifier=project_identifier,
            x_neptune_client_metadata=x_neptune_client_metadata,
        )
    ).parsed



#
# Copyright (c) 2025, Neptune Labs Sp. z o.o.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__all__ = ["exchange_api_key"]

from typing import cast

from .api.backend import exchange_api_token
from .client import (
    AuthenticatedClient,
    Client,
)
from .credentials import Credentials
from .errors import (
    ApiKeyRejectedError,
    UnableToExchangeApiKeyError,
)
from .models import Error
from .types import OAuthToken


def exchange_api_key(client: Client, credentials: Credentials) -> OAuthToken:
    # We cast `client` to keep mypy happy. exchange_api_token.sync_detailed() generated by OpenAPI
    # generator accepts AuthenticatedClient, while user code expects to pass an unauthenticated Client instance.
    # They work interchangeably in this context.
    response = exchange_api_token.sync_detailed(
        client=cast(AuthenticatedClient, client), x_neptune_api_token=credentials.api_key
    )

    # HTTP 401 is an indicator that the API token is rejected by the server
    if response.status_code == 401:
        raise ApiKeyRejectedError()

    token_data = response.parsed
    if isinstance(token_data, Error):
        raise UnableToExchangeApiKeyError(
            reason=f"Unexpected response from Neptune API: HTTP {response.status_code} ({token_data.message})"
        )

    if response.status_code != 200 or not token_data:
        raise UnableToExchangeApiKeyError(reason=f"Unexpected response from Neptune API: HTTP {response.status_code}")

    return OAuthToken.from_tokens(access=token_data.access_token, refresh=token_data.refresh_token)



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_sym_db = _symbol_database.Default()
from .....neptune_pb.api.v1.model import leaderboard_entries_pb2 as neptune__pb_dot_api_dot_v1_dot_model_dot_leaderboard__entries__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(neptune_pb/api/v1/model/attributes.proto\x12\x14neptune.api.v1.model\x1a1neptune_pb/api/v1/model/leaderboard_entries.proto"d\n\x1eProtoAttributesSearchResultDTO\x12B\n\x07entries\x18\x01 \x03(\x0b21.neptune.api.v1.model.ProtoAttributeDefinitionDTO"9\n\x1bProtoAttributeDefinitionDTO\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t"\xa9\x01\n\x1dProtoQueryAttributesResultDTO\x12N\n\x07entries\x18\x01 \x03(\x0b2=.neptune.api.v1.model.ProtoQueryAttributesExperimentResultDTO\x128\n\x08nextPage\x18\x02 \x01(\x0b2&.neptune.api.v1.model.ProtoNextPageDTO"^\n\x10ProtoNextPageDTO\x12\x1a\n\rnextPageToken\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05limit\x18\x02 \x01(\rH\x01\x88\x01\x01B\x10\n\x0e_nextPageTokenB\x08\n\x06_limit"\x97\x01\n\'ProtoQueryAttributesExperimentResultDTO\x12\x14\n\x0cexperimentId\x18\x01 \x01(\t\x12\x19\n\x11experimentShortId\x18\x02 \x01(\t\x12;\n\nattributes\x18\x03 \x03(\x0b2\'.neptune.api.v1.model.ProtoAttributeDTOB4\n0ml.neptune.leaderboard.api.model.proto.generatedP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neptune_pb.api.v1.model.attributes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals['DESCRIPTOR']._options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n0ml.neptune.leaderboard.api.model.proto.generatedP\x01'
    _globals['_PROTOATTRIBUTESSEARCHRESULTDTO']._serialized_start = 117
    _globals['_PROTOATTRIBUTESSEARCHRESULTDTO']._serialized_end = 217
    _globals['_PROTOATTRIBUTEDEFINITIONDTO']._serialized_start = 219
    _globals['_PROTOATTRIBUTEDEFINITIONDTO']._serialized_end = 276
    _globals['_PROTOQUERYATTRIBUTESRESULTDTO']._serialized_start = 279
    _globals['_PROTOQUERYATTRIBUTESRESULTDTO']._serialized_end = 448
    _globals['_PROTONEXTPAGEDTO']._serialized_start = 450
    _globals['_PROTONEXTPAGEDTO']._serialized_end = 544
    _globals['_PROTOQUERYATTRIBUTESEXPERIMENTRESULTDTO']._serialized_start = 547
    _globals['_PROTOQUERYATTRIBUTESEXPERIMENTRESULTDTO']._serialized_end = 698


#
# Copyright (c) 2025, Neptune Labs Sp. z o.o.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import (
    TYPE_CHECKING,
    Any,
    Dict,
    List,
    Type,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.series_values_request_order import SeriesValuesRequestOrder
from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
    from ..models.open_range_dto import OpenRangeDTO
    from ..models.series_values_request_series import SeriesValuesRequestSeries


T = TypeVar("T", bound="SeriesValuesRequest")


@_attrs_define
class SeriesValuesRequest:
    """
    Attributes:
        requests (List['SeriesValuesRequestSeries']):
        order (Union[Unset, SeriesValuesRequestOrder]):
        per_series_points_limit (Union[Unset, int]):
        size_limit_bytes (Union[Unset, int]):
        step_range (Union[Unset, OpenRangeDTO]):
    """

    requests: List["SeriesValuesRequestSeries"]
    order: Union[Unset, SeriesValuesRequestOrder] = UNSET
    per_series_points_limit: Union[Unset, int] = UNSET
    size_limit_bytes: Union[Unset, int] = UNSET
    step_range: Union[Unset, "OpenRangeDTO"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        requests = []
        for requests_item_data in self.requests:
            requests_item = requests_item_data.to_dict()
            requests.append(requests_item)

        order: Union[Unset, str] = UNSET
        if not isinstance(self.order, Unset):
            order = self.order.value

        per_series_points_limit = self.per_series_points_limit

        size_limit_bytes = self.size_limit_bytes

        step_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.step_range, Unset):
            step_range = self.step_range.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "requests": requests,
            }
        )
        if order is not UNSET:
            field_dict["order"] = order
        if per_series_points_limit is not UNSET:
            field_dict["perSeriesPointsLimit"] = per_series_points_limit
        if size_limit_bytes is not UNSET:
            field_dict["sizeLimitBytes"] = size_limit_bytes
        if step_range is not UNSET:
            field_dict["stepRange"] = step_range

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.open_range_dto import OpenRangeDTO
        from ..models.series_values_request_series import SeriesValuesRequestSeries

        d = src_dict.copy()
        requests = []
        _requests = d.pop("requests")
        for requests_item_data in _requests:
            requests_item = SeriesValuesRequestSeries.from_dict(requests_item_data)

            requests.append(requests_item)

        _order = d.pop("order", UNSET)
        order: Union[Unset, SeriesValuesRequestOrder]
        if isinstance(_order, Unset):
            order = UNSET
        else:
            order = SeriesValuesRequestOrder(_order)

        per_series_points_limit = d.pop("perSeriesPointsLimit", UNSET)

        size_limit_bytes = d.pop("sizeLimitBytes", UNSET)

        _step_range = d.pop("stepRange", UNSET)
        step_range: Union[Unset, OpenRangeDTO]
        if isinstance(_step_range, Unset):
            step_range = UNSET
        else:
            step_range = OpenRangeDTO.from_dict(_step_range)

        series_values_request = cls(
            requests=requests,
            order=order,
            per_series_points_limit=per_series_points_limit,
            size_limit_bytes=size_limit_bytes,
            step_range=step_range,
        )

        series_values_request.additional_properties = d
        return series_values_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
from ..... import neptune_pb
import typing
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ProtoLeaderboardEntriesSearchResultDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MATCHING_ITEM_COUNT_FIELD_NUMBER: builtins.int
    TOTAL_GROUP_COUNT_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    matching_item_count: builtins.int
    total_group_count: builtins.int

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoAttributesDTO]:
        ...

    def __init__(self, *, matching_item_count: builtins.int=..., total_group_count: builtins.int | None=..., entries: collections.abc.Iterable[global___ProtoAttributesDTO] | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_total_group_count', b'_total_group_count', 'total_group_count', b'total_group_count']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_total_group_count', b'_total_group_count', 'entries', b'entries', 'matching_item_count', b'matching_item_count', 'total_group_count', b'total_group_count']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['_total_group_count', b'_total_group_count']) -> typing.Literal['total_group_count'] | None:
        ...
global___ProtoLeaderboardEntriesSearchResultDTO = ProtoLeaderboardEntriesSearchResultDTO

@typing.final
class ProtoAttributesDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    experiment_id: builtins.str
    type: builtins.str
    project_id: builtins.str
    organization_id: builtins.str
    project_name: builtins.str
    organization_name: builtins.str

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoAttributeDTO]:
        ...

    def __init__(self, *, experiment_id: builtins.str=..., type: builtins.str=..., project_id: builtins.str=..., organization_id: builtins.str=..., project_name: builtins.str=..., organization_name: builtins.str=..., attributes: collections.abc.Iterable[global___ProtoAttributeDTO] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attributes', b'attributes', 'experiment_id', b'experiment_id', 'organization_id', b'organization_id', 'organization_name', b'organization_name', 'project_id', b'project_id', 'project_name', b'project_name', 'type', b'type']) -> None:
        ...
global___ProtoAttributesDTO = ProtoAttributesDTO

@typing.final
class ProtoAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    INT_PROPERTIES_FIELD_NUMBER: builtins.int
    FLOAT_PROPERTIES_FIELD_NUMBER: builtins.int
    STRING_PROPERTIES_FIELD_NUMBER: builtins.int
    BOOL_PROPERTIES_FIELD_NUMBER: builtins.int
    DATETIME_PROPERTIES_FIELD_NUMBER: builtins.int
    STRING_SET_PROPERTIES_FIELD_NUMBER: builtins.int
    FLOAT_SERIES_PROPERTIES_FIELD_NUMBER: builtins.int
    FILE_REF_PROPERTIES_FIELD_NUMBER: builtins.int
    STRING_SERIES_PROPERTIES_FIELD_NUMBER: builtins.int
    FILE_REF_SERIES_PROPERTIES_FIELD_NUMBER: builtins.int
    HISTOGRAM_SERIES_PROPERTIES_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str

    @property
    def int_properties(self) -> global___ProtoIntAttributeDTO:
        ...

    @property
    def float_properties(self) -> global___ProtoFloatAttributeDTO:
        ...

    @property
    def string_properties(self) -> global___ProtoStringAttributeDTO:
        ...

    @property
    def bool_properties(self) -> global___ProtoBoolAttributeDTO:
        ...

    @property
    def datetime_properties(self) -> global___ProtoDatetimeAttributeDTO:
        ...

    @property
    def string_set_properties(self) -> global___ProtoStringSetAttributeDTO:
        ...

    @property
    def float_series_properties(self) -> global___ProtoFloatSeriesAttributeDTO:
        ...

    @property
    def file_ref_properties(self) -> global___ProtoFileRefAttributeDTO:
        ...

    @property
    def string_series_properties(self) -> global___ProtoStringSeriesAttributeDTO:
        ...

    @property
    def file_ref_series_properties(self) -> global___ProtoFileRefSeriesAttributeDTO:
        ...

    @property
    def histogram_series_properties(self) -> global___ProtoHistogramSeriesAttributeDTO:
        ...

    def __init__(self, *, name: builtins.str=..., type: builtins.str=..., int_properties: global___ProtoIntAttributeDTO | None=..., float_properties: global___ProtoFloatAttributeDTO | None=..., string_properties: global___ProtoStringAttributeDTO | None=..., bool_properties: global___ProtoBoolAttributeDTO | None=..., datetime_properties: global___ProtoDatetimeAttributeDTO | None=..., string_set_properties: global___ProtoStringSetAttributeDTO | None=..., float_series_properties: global___ProtoFloatSeriesAttributeDTO | None=..., file_ref_properties: global___ProtoFileRefAttributeDTO | None=..., string_series_properties: global___ProtoStringSeriesAttributeDTO | None=..., file_ref_series_properties: global___ProtoFileRefSeriesAttributeDTO | None=..., histogram_series_properties: global___ProtoHistogramSeriesAttributeDTO | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_bool_properties', b'_bool_properties', '_datetime_properties', b'_datetime_properties', '_file_ref_properties', b'_file_ref_properties', '_file_ref_series_properties', b'_file_ref_series_properties', '_float_properties', b'_float_properties', '_float_series_properties', b'_float_series_properties', '_histogram_series_properties', b'_histogram_series_properties', '_int_properties', b'_int_properties', '_string_properties', b'_string_properties', '_string_series_properties', b'_string_series_properties', '_string_set_properties', b'_string_set_properties', 'bool_properties', b'bool_properties', 'datetime_properties', b'datetime_properties', 'file_ref_properties', b'file_ref_properties', 'file_ref_series_properties', b'file_ref_series_properties', 'float_properties', b'float_properties', 'float_series_properties', b'float_series_properties', 'histogram_series_properties', b'histogram_series_properties', 'int_properties', b'int_properties', 'string_properties', b'string_properties', 'string_series_properties', b'string_series_properties', 'string_set_properties', b'string_set_properties']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_bool_properties', b'_bool_properties', '_datetime_properties', b'_datetime_properties', '_file_ref_properties', b'_file_ref_properties', '_file_ref_series_properties', b'_file_ref_series_properties', '_float_properties', b'_float_properties', '_float_series_properties', b'_float_series_properties', '_histogram_series_properties', b'_histogram_series_properties', '_int_properties', b'_int_properties', '_string_properties', b'_string_properties', '_string_series_properties', b'_string_series_properties', '_string_set_properties', b'_string_set_properties', 'bool_properties', b'bool_properties', 'datetime_properties', b'datetime_properties', 'file_ref_properties', b'file_ref_properties', 'file_ref_series_properties', b'file_ref_series_properties', 'float_properties', b'float_properties', 'float_series_properties', b'float_series_properties', 'histogram_series_properties', b'histogram_series_properties', 'int_properties', b'int_properties', 'name', b'name', 'string_properties', b'string_properties', 'string_series_properties', b'string_series_properties', 'string_set_properties', b'string_set_properties', 'type', b'type']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_bool_properties', b'_bool_properties']) -> typing.Literal['bool_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_datetime_properties', b'_datetime_properties']) -> typing.Literal['datetime_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_file_ref_properties', b'_file_ref_properties']) -> typing.Literal['file_ref_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_file_ref_series_properties', b'_file_ref_series_properties']) -> typing.Literal['file_ref_series_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_float_properties', b'_float_properties']) -> typing.Literal['float_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_float_series_properties', b'_float_series_properties']) -> typing.Literal['float_series_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_histogram_series_properties', b'_histogram_series_properties']) -> typing.Literal['histogram_series_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_int_properties', b'_int_properties']) -> typing.Literal['int_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_string_properties', b'_string_properties']) -> typing.Literal['string_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_string_series_properties', b'_string_series_properties']) -> typing.Literal['string_series_properties'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_string_set_properties', b'_string_set_properties']) -> typing.Literal['string_set_properties'] | None:
        ...
global___ProtoAttributeDTO = ProtoAttributeDTO

@typing.final
class ProtoIntAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    value: builtins.int

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., value: builtins.int=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'value', b'value']) -> None:
        ...
global___ProtoIntAttributeDTO = ProtoIntAttributeDTO

@typing.final
class ProtoFloatAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    value: builtins.float

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., value: builtins.float=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'value', b'value']) -> None:
        ...
global___ProtoFloatAttributeDTO = ProtoFloatAttributeDTO

@typing.final
class ProtoStringAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    value: builtins.str

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., value: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'value', b'value']) -> None:
        ...
global___ProtoStringAttributeDTO = ProtoStringAttributeDTO

@typing.final
class ProtoBoolAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    value: builtins.bool

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., value: builtins.bool=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'value', b'value']) -> None:
        ...
global___ProtoBoolAttributeDTO = ProtoBoolAttributeDTO

@typing.final
class ProtoDatetimeAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    value: builtins.int

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., value: builtins.int=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'value', b'value']) -> None:
        ...
global___ProtoDatetimeAttributeDTO = ProtoDatetimeAttributeDTO

@typing.final
class ProtoStringSetAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str

    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        ...

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., value: collections.abc.Iterable[builtins.str] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'value', b'value']) -> None:
        ...
global___ProtoStringSetAttributeDTO = ProtoStringSetAttributeDTO

@typing.final
class ProtoFloatSeriesAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    LAST_STEP_FIELD_NUMBER: builtins.int
    LAST_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    AVERAGE_FIELD_NUMBER: builtins.int
    VARIANCE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    HAS_PREVIEW_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    last_step: builtins.float
    last: builtins.float
    min: builtins.float
    max: builtins.float
    average: builtins.float
    variance: builtins.float
    has_preview: builtins.bool

    @property
    def config(self) -> global___ProtoFloatSeriesAttributeConfigDTO:
        ...

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., last_step: builtins.float | None=..., last: builtins.float | None=..., min: builtins.float | None=..., max: builtins.float | None=..., average: builtins.float | None=..., variance: builtins.float | None=..., config: global___ProtoFloatSeriesAttributeConfigDTO | None=..., has_preview: builtins.bool=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_average', b'_average', '_last', b'_last', '_last_step', b'_last_step', '_max', b'_max', '_min', b'_min', '_variance', b'_variance', 'average', b'average', 'config', b'config', 'last', b'last', 'last_step', b'last_step', 'max', b'max', 'min', b'min', 'variance', b'variance']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_average', b'_average', '_last', b'_last', '_last_step', b'_last_step', '_max', b'_max', '_min', b'_min', '_variance', b'_variance', 'attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'average', b'average', 'config', b'config', 'has_preview', b'has_preview', 'last', b'last', 'last_step', b'last_step', 'max', b'max', 'min', b'min', 'variance', b'variance']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_average', b'_average']) -> typing.Literal['average'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last', b'_last']) -> typing.Literal['last'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last_step', b'_last_step']) -> typing.Literal['last_step'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_max', b'_max']) -> typing.Literal['max'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_min', b'_min']) -> typing.Literal['min'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_variance', b'_variance']) -> typing.Literal['variance'] | None:
        ...
global___ProtoFloatSeriesAttributeDTO = ProtoFloatSeriesAttributeDTO

@typing.final
class ProtoFloatSeriesAttributeConfigDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MIN_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    min: builtins.float
    max: builtins.float
    unit: builtins.str

    def __init__(self, *, min: builtins.float | None=..., max: builtins.float | None=..., unit: builtins.str | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_max', b'_max', '_min', b'_min', '_unit', b'_unit', 'max', b'max', 'min', b'min', 'unit', b'unit']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_max', b'_max', '_min', b'_min', '_unit', b'_unit', 'max', b'max', 'min', b'min', 'unit', b'unit']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_max', b'_max']) -> typing.Literal['max'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_min', b'_min']) -> typing.Literal['min'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_unit', b'_unit']) -> typing.Literal['unit'] | None:
        ...
global___ProtoFloatSeriesAttributeConfigDTO = ProtoFloatSeriesAttributeConfigDTO

@typing.final
class ProtoFileRefAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SIZEBYTES_FIELD_NUMBER: builtins.int
    MIMETYPE_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    path: builtins.str
    sizeBytes: builtins.int
    mimeType: builtins.str

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., path: builtins.str=..., sizeBytes: builtins.int=..., mimeType: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'mimeType', b'mimeType', 'path', b'path', 'sizeBytes', b'sizeBytes']) -> None:
        ...
global___ProtoFileRefAttributeDTO = ProtoFileRefAttributeDTO

@typing.final
class ProtoStringSeriesAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    LAST_STEP_FIELD_NUMBER: builtins.int
    LAST_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    last_step: builtins.float
    last: builtins.str

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., last_step: builtins.float | None=..., last: builtins.str | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_last', b'_last', '_last_step', b'_last_step', 'last', b'last', 'last_step', b'last_step']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_last', b'_last', '_last_step', b'_last_step', 'attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'last', b'last', 'last_step', b'last_step']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last', b'_last']) -> typing.Literal['last'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last_step', b'_last_step']) -> typing.Literal['last_step'] | None:
        ...
global___ProtoStringSeriesAttributeDTO = ProtoStringSeriesAttributeDTO

@typing.final
class ProtoFileRefSeriesAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    LAST_STEP_FIELD_NUMBER: builtins.int
    LAST_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    last_step: builtins.float

    @property
    def last(self) -> neptune_pb.api.v1.model.series_values_pb2.ProtoFileRef:
        ...

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., last_step: builtins.float | None=..., last: neptune_pb.api.v1.model.series_values_pb2.ProtoFileRef | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_last', b'_last', '_last_step', b'_last_step', 'last', b'last', 'last_step', b'last_step']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_last', b'_last', '_last_step', b'_last_step', 'attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'last', b'last', 'last_step', b'last_step']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last', b'_last']) -> typing.Literal['last'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last_step', b'_last_step']) -> typing.Literal['last_step'] | None:
        ...
global___ProtoFileRefSeriesAttributeDTO = ProtoFileRefSeriesAttributeDTO

@typing.final
class ProtoHistogramSeriesAttributeDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    LAST_STEP_FIELD_NUMBER: builtins.int
    LAST_FIELD_NUMBER: builtins.int
    attribute_name: builtins.str
    attribute_type: builtins.str
    last_step: builtins.float

    @property
    def last(self) -> neptune_pb.api.v1.model.series_values_pb2.ProtoHistogram:
        ...

    def __init__(self, *, attribute_name: builtins.str=..., attribute_type: builtins.str=..., last_step: builtins.float | None=..., last: neptune_pb.api.v1.model.series_values_pb2.ProtoHistogram | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_last', b'_last', '_last_step', b'_last_step', 'last', b'last', 'last_step', b'last_step']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_last', b'_last', '_last_step', b'_last_step', 'attribute_name', b'attribute_name', 'attribute_type', b'attribute_type', 'last', b'last', 'last_step', b'last_step']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last', b'_last']) -> typing.Literal['last'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_last_step', b'_last_step']) -> typing.Literal['last_step'] | None:
        ...
global___ProtoHistogramSeriesAttributeDTO = ProtoHistogramSeriesAttributeDTO


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_sym_db = _symbol_database.Default()
from ....google_rpc import code_pb2 as google__rpc_dot_code__pb2
from ....neptune_pb.ingest.v1 import common_pb2 as neptune__pb_dot_ingest_dot_v1_dot_common__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!neptune_pb/ingest/v1/ingest.proto\x12\x11neptune.ingest.v1\x1a\x15google_rpc/code.proto\x1a!neptune_pb/ingest/v1/common.proto"0\n\x0cBatchContext\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0f\n\x07api_key\x18\x02 \x01(\x0c"V\n\tUpdateRun\x12A\n\x10update_snapshots\x18\x08 \x01(\x0b2%.neptune.ingest.v1.UpdateRunSnapshotsH\x00B\x06\n\x04mode"\xb8\x02\n\x16BatchProjectOperations\x120\n\x07context\x18\x01 \x01(\x0b2\x1f.neptune.ingest.v1.BatchContext\x12\x1e\n\x16create_missing_project\x18\x03 \x01(\x08\x12+\n\x0bcreate_runs\x18\x04 \x03(\x0b2\x16.neptune.ingest.v1.Run\x12N\n\x0bupdate_runs\x18\x08 \x03(\x0b29.neptune.ingest.v1.BatchProjectOperations.UpdateRunsEntry\x1aO\n\x0fUpdateRunsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b2\x1c.neptune.ingest.v1.UpdateRun:\x028\x01"z\n\x0eCreateRunError\x12#\n\tgrpc_code\x18\x01 \x01(\x0e2\x10.google_rpc.Code\x122\n\x0bingest_code\x18\x03 \x01(\x0e2\x1d.neptune.ingest.v1.IngestCode\x12\x0f\n\x07message\x18\x02 \x01(\t"t\n\x0fCreateRunResult\x12%\n\x03run\x18\x01 \x01(\x0b2\x16.neptune.ingest.v1.RunH\x00\x122\n\x05error\x18\x02 \x01(\x0b2!.neptune.ingest.v1.CreateRunErrorH\x00B\x06\n\x04type"\xb4\x03\n\rResultSummary\x12\x1e\n\x16total_operations_count\x18\x01 \x01(\x03\x12\x18\n\x10successful_count\x18\x02 \x01(\x03\x12\x14\n\x0cfailed_count\x18\x03 \x01(\x03\x12V\n\x13failed_by_grpc_code\x18\x04 \x03(\x0b29.neptune.ingest.v1.ResultSummary.FailedByGRPCCodeCounters\x12R\n\x15failed_by_ingest_code\x18\x05 \x03(\x0b23.neptune.ingest.v1.ResultSummary.IngestCodeCounters\x1aN\n\x18FailedByGRPCCodeCounters\x12#\n\tgrpc_code\x18\x01 \x01(\x0e2\x10.google_rpc.Code\x12\r\n\x05count\x18\x02 \x01(\x03\x1aW\n\x12IngestCodeCounters\x122\n\x0bingest_code\x18\x01 \x01(\x0e2\x1d.neptune.ingest.v1.IngestCode\x12\r\n\x05count\x18\x02 \x01(\x03"\x89\x01\n\x0eUpdateRunError\x12#\n\tgrpc_code\x18\x01 \x01(\x0e2\x10.google_rpc.Code\x122\n\x0bingest_code\x18\x02 \x01(\x0e2\x1d.neptune.ingest.v1.IngestCode\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\r\n\x05field\x18\x04 \x01(\t"\x8a\x01\n\x10UpdateRunResults\x12<\n\x12operations_summary\x18\x01 \x01(\x0b2 .neptune.ingest.v1.ResultSummary\x128\n\rupdate_errors\x18\x02 \x03(\x0b2!.neptune.ingest.v1.UpdateRunError"\xb6\x03\n\x0bBatchResult\x12#\n\tgrpc_code\x18\x01 \x01(\x0e2\x10.google_rpc.Code\x122\n\x0bingest_code\x18\t \x01(\x0e2\x1d.neptune.ingest.v1.IngestCode\x12<\n\x12operations_summary\x18\x02 \x01(\x0b2 .neptune.ingest.v1.ResultSummary\x12\x0f\n\x07project\x18\x05 \x01(\t\x12>\n\x12create_run_results\x18\x06 \x03(\x0b2".neptune.ingest.v1.CreateRunResult\x12P\n\x12update_run_results\x18\x07 \x03(\x0b24.neptune.ingest.v1.BatchResult.UpdateRunResultsEntry\x12\x0f\n\x07message\x18\x08 \x01(\t\x1a\\\n\x15UpdateRunResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x122\n\x05value\x18\x02 \x01(\x0b2#.neptune.ingest.v1.UpdateRunResults:\x028\x01"K\n\rIngestRequest\x12:\n\x07batches\x18\x01 \x03(\x0b2).neptune.ingest.v1.BatchProjectOperations"\x91\x01\n\x0eIngestResponse\x121\n\x07summary\x18\x02 \x01(\x0b2 .neptune.ingest.v1.ResultSummary\x12\x15\n\rerror_message\x18\x04 \x01(\t\x125\n\rbatch_results\x18\x05 \x03(\x0b2\x1e.neptune.ingest.v1.BatchResult*\xe8\x07\n\nIngestCode\x12\x06\n\x02OK\x10\x00\x12!\n\x1dBATCH_CONTAINS_DEPENDENT_RUNS\x10\x04\x12\x15\n\x11PROJECT_NOT_FOUND\x10\x08\x12\x18\n\x14PROJECT_INVALID_NAME\x10\t\x12\x11\n\rRUN_NOT_FOUND\x10\n\x12\x11\n\rRUN_DUPLICATE\x10\x0b\x12\x13\n\x0fRUN_CONFLICTING\x10\x0c\x12\x1d\n\x19RUN_FORK_PARENT_NOT_FOUND\x10\r\x12#\n\x1fRUN_INVALID_CREATION_PARAMETERS\x10\x0e\x12!\n\x1dFIELD_PATH_EXCEEDS_SIZE_LIMIT\x10\x10\x12\x14\n\x10FIELD_PATH_EMPTY\x10\x11\x12\x16\n\x12FIELD_PATH_INVALID\x10\x12\x12\x1b\n\x17FIELD_PATH_NON_WRITABLE\x10\x13\x12\x1a\n\x16FIELD_TYPE_UNSUPPORTED\x10\x14\x12\x1a\n\x16FIELD_TYPE_CONFLICTING\x10\x15\x12\x1a\n\x16SERIES_POINT_DUPLICATE\x10\x18\x12\x19\n\x15SERIES_STEP_TOO_LARGE\x10(\x12\x17\n\x13SERIES_STEP_INVALID\x10)\x125\n1SERIES_PREVIEW_STEP_NOT_AFTER_LAST_COMMITTED_STEP\x10*\x12\x1e\n\x1aSERIES_STEP_NON_INCREASING\x10\x19\x12$\n SERIES_STEP_NOT_AFTER_FORK_POINT\x10\x1a\x12\x1f\n\x1bSERIES_TIMESTAMP_DECREASING\x10\x1b\x12#\n\x1fFLOAT_VALUE_NAN_INF_UNSUPPORTED\x10 \x12\x1f\n\x1bDATETIME_VALUE_OUT_OF_RANGE\x10!\x12#\n\x1fSTRING_VALUE_EXCEEDS_SIZE_LIMIT\x10$\x12!\n\x1dSTRING_SET_EXCEEDS_SIZE_LIMIT\x10%\x12\x1f\n\x1bFILE_REF_EXCEEDS_SIZE_LIMIT\x10&\x12$\n HISTOGRAM_BIN_EDGES_CONTAINS_NAN\x102\x12\x1b\n\x17HISTOGRAM_TOO_MANY_BINS\x103\x12&\n"HISTOGRAM_BIN_EDGES_NOT_INCREASING\x104\x12-\n)HISTOGRAM_VALUES_LENGTH_DOESNT_MATCH_BINS\x105\x12\x14\n\x10INGEST_SUSPENDED\x10?\x12\x0c\n\x08INTERNAL\x10@B5\n$ml.neptune.leaderboard.api.ingest.v1B\x0bIngestProtoP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neptune_pb.ingest.v1.ingest_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals['DESCRIPTOR']._options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n$ml.neptune.leaderboard.api.ingest.v1B\x0bIngestProtoP\x01'
    _globals['_BATCHPROJECTOPERATIONS_UPDATERUNSENTRY']._options = None
    _globals['_BATCHPROJECTOPERATIONS_UPDATERUNSENTRY']._serialized_options = b'8\x01'
    _globals['_BATCHRESULT_UPDATERUNRESULTSENTRY']._options = None
    _globals['_BATCHRESULT_UPDATERUNRESULTSENTRY']._serialized_options = b'8\x01'
    _globals['_INGESTCODE']._serialized_start = 2196
    _globals['_INGESTCODE']._serialized_end = 3196
    _globals['_BATCHCONTEXT']._serialized_start = 114
    _globals['_BATCHCONTEXT']._serialized_end = 162
    _globals['_UPDATERUN']._serialized_start = 164
    _globals['_UPDATERUN']._serialized_end = 250
    _globals['_BATCHPROJECTOPERATIONS']._serialized_start = 253
    _globals['_BATCHPROJECTOPERATIONS']._serialized_end = 565
    _globals['_BATCHPROJECTOPERATIONS_UPDATERUNSENTRY']._serialized_start = 486
    _globals['_BATCHPROJECTOPERATIONS_UPDATERUNSENTRY']._serialized_end = 565
    _globals['_CREATERUNERROR']._serialized_start = 567
    _globals['_CREATERUNERROR']._serialized_end = 689
    _globals['_CREATERUNRESULT']._serialized_start = 691
    _globals['_CREATERUNRESULT']._serialized_end = 807
    _globals['_RESULTSUMMARY']._serialized_start = 810
    _globals['_RESULTSUMMARY']._serialized_end = 1246
    _globals['_RESULTSUMMARY_FAILEDBYGRPCCODECOUNTERS']._serialized_start = 1079
    _globals['_RESULTSUMMARY_FAILEDBYGRPCCODECOUNTERS']._serialized_end = 1157
    _globals['_RESULTSUMMARY_INGESTCODECOUNTERS']._serialized_start = 1159
    _globals['_RESULTSUMMARY_INGESTCODECOUNTERS']._serialized_end = 1246
    _globals['_UPDATERUNERROR']._serialized_start = 1249
    _globals['_UPDATERUNERROR']._serialized_end = 1386
    _globals['_UPDATERUNRESULTS']._serialized_start = 1389
    _globals['_UPDATERUNRESULTS']._serialized_end = 1527
    _globals['_BATCHRESULT']._serialized_start = 1530
    _globals['_BATCHRESULT']._serialized_end = 1968
    _globals['_BATCHRESULT_UPDATERUNRESULTSENTRY']._serialized_start = 1876
    _globals['_BATCHRESULT_UPDATERUNRESULTSENTRY']._serialized_end = 1968
    _globals['_INGESTREQUEST']._serialized_start = 1970
    _globals['_INGESTREQUEST']._serialized_end = 2045
    _globals['_INGESTRESPONSE']._serialized_start = 2048
    _globals['_INGESTRESPONSE']._serialized_end = 2193


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
from ..... import neptune_pb
import typing
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ProtoAttributesSearchResultDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ENTRIES_FIELD_NUMBER: builtins.int

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoAttributeDefinitionDTO]:
        ...

    def __init__(self, *, entries: collections.abc.Iterable[global___ProtoAttributeDefinitionDTO] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['entries', b'entries']) -> None:
        ...
global___ProtoAttributesSearchResultDTO = ProtoAttributesSearchResultDTO

@typing.final
class ProtoAttributeDefinitionDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str

    def __init__(self, *, name: builtins.str=..., type: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['name', b'name', 'type', b'type']) -> None:
        ...
global___ProtoAttributeDefinitionDTO = ProtoAttributeDefinitionDTO

@typing.final
class ProtoQueryAttributesResultDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ENTRIES_FIELD_NUMBER: builtins.int
    NEXTPAGE_FIELD_NUMBER: builtins.int

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProtoQueryAttributesExperimentResultDTO]:
        ...

    @property
    def nextPage(self) -> global___ProtoNextPageDTO:
        ...

    def __init__(self, *, entries: collections.abc.Iterable[global___ProtoQueryAttributesExperimentResultDTO] | None=..., nextPage: global___ProtoNextPageDTO | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['nextPage', b'nextPage']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['entries', b'entries', 'nextPage', b'nextPage']) -> None:
        ...
global___ProtoQueryAttributesResultDTO = ProtoQueryAttributesResultDTO

@typing.final
class ProtoNextPageDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NEXTPAGETOKEN_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    nextPageToken: builtins.str
    limit: builtins.int

    def __init__(self, *, nextPageToken: builtins.str | None=..., limit: builtins.int | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_limit', b'_limit', '_nextPageToken', b'_nextPageToken', 'limit', b'limit', 'nextPageToken', b'nextPageToken']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_limit', b'_limit', '_nextPageToken', b'_nextPageToken', 'limit', b'limit', 'nextPageToken', b'nextPageToken']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_limit', b'_limit']) -> typing.Literal['limit'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_nextPageToken', b'_nextPageToken']) -> typing.Literal['nextPageToken'] | None:
        ...
global___ProtoNextPageDTO = ProtoNextPageDTO

@typing.final
class ProtoQueryAttributesExperimentResultDTO(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPERIMENTID_FIELD_NUMBER: builtins.int
    EXPERIMENTSHORTID_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    experimentId: builtins.str
    experimentShortId: builtins.str

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[neptune_pb.api.v1.model.leaderboard_entries_pb2.ProtoAttributeDTO]:
        ...

    def __init__(self, *, experimentId: builtins.str=..., experimentShortId: builtins.str=..., attributes: collections.abc.Iterable[neptune_pb.api.v1.model.leaderboard_entries_pb2.ProtoAttributeDTO] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['attributes', b'attributes', 'experimentId', b'experimentId', 'experimentShortId', b'experimentShortId']) -> None:
        ...
global___ProtoQueryAttributesExperimentResultDTO = ProtoQueryAttributesExperimentResultDTO


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&neptune_pb/api/v1/model/requests.proto\x12\x14neptune.api.v1.model"\x93\x01\n ProtoGetTimeseriesBucketsRequest\x12@\n\x0bexpressions\x18\x01 \x03(\x0b2+.neptune.api.v1.model.ProtoCustomExpression\x12-\n\x04view\x18\x02 \x01(\x0b2\x1f.neptune.api.v1.model.ProtoView"\xf3\x01\n\x15ProtoCustomExpression\x12\x11\n\trequestId\x18\x01 \x01(\t\x12\r\n\x05runId\x18\x02 \x01(\t\x12\x16\n\x0ecustomYFormula\x18\x03 \x01(\t\x12\x1b\n\x0eincludePreview\x18\x04 \x01(\x08H\x00\x88\x01\x01\x123\n\x07lineage\x18\x05 \x01(\x0e2".neptune.api.v1.model.ProtoLineage\x12;\n\nentityType\x18\x06 \x01(\x0e2\'.neptune.api.v1.model.LineageEntityTypeB\x11\n\x0f_includePreview"\xbd\x02\n\tProtoView\x12\x11\n\x04from\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x0f\n\x02to\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12B\n\x0cpointFilters\x18\x03 \x01(\x0b2\'.neptune.api.v1.model.ProtoPointFiltersH\x02\x88\x01\x01\x12\x12\n\nmaxBuckets\x18\x04 \x01(\x05\x120\n\x06xScale\x18\x05 \x01(\x0e2 .neptune.api.v1.model.ProtoScale\x120\n\x06yScale\x18\x06 \x01(\x0e2 .neptune.api.v1.model.ProtoScale\x12/\n\x05xAxis\x18\x07 \x01(\x0b2 .neptune.api.v1.model.ProtoXAxisB\x07\n\x05_fromB\x05\n\x03_toB\x0f\n\r_pointFilters"_\n\x11ProtoPointFilters\x12<\n\tstepRange\x18\x01 \x01(\x0b2$.neptune.api.v1.model.ProtoOpenRangeH\x00\x88\x01\x01B\x0c\n\n_stepRange"D\n\x0eProtoOpenRange\x12\x11\n\x04from\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x0f\n\x02to\x18\x02 \x01(\x01H\x01\x88\x01\x01B\x07\n\x05_fromB\x05\n\x03_to"\xed\x01\n\nProtoXAxis\x12-\n\x05steps\x18\x01 \x01(\x0b2\x1c.neptune.api.v1.model.XStepsH\x00\x129\n\x0bepochMillis\x18\x02 \x01(\x0b2".neptune.api.v1.model.XEpochMillisH\x00\x12;\n\x0crelativeTime\x18\x03 \x01(\x0b2#.neptune.api.v1.model.XRelativeTimeH\x00\x12/\n\x06custom\x18\x04 \x01(\x0b2\x1d.neptune.api.v1.model.XCustomH\x00B\x07\n\x05value"\x08\n\x06XSteps"\x0e\n\x0cXEpochMillis"\x0f\n\rXRelativeTime"\x1d\n\x07XCustom\x12\x12\n\nexpression\x18\x01 \x01(\t*!\n\nProtoScale\x12\n\n\x06linear\x10\x00\x12\x07\n\x03log\x10\x01*(\n\x0cProtoLineage\x12\x08\n\x04FULL\x10\x00\x12\x0e\n\nONLY_OWNED\x10\x01*,\n\x11LineageEntityType\x12\x0e\n\nEXPERIMENT\x10\x00\x12\x07\n\x03RUN\x10\x01B4\n0ml.neptune.leaderboard.api.model.proto.generatedP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neptune_pb.api.v1.model.requests_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals['DESCRIPTOR']._options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n0ml.neptune.leaderboard.api.model.proto.generatedP\x01'
    _globals['_PROTOSCALE']._serialized_start = 1261
    _globals['_PROTOSCALE']._serialized_end = 1294
    _globals['_PROTOLINEAGE']._serialized_start = 1296
    _globals['_PROTOLINEAGE']._serialized_end = 1336
    _globals['_LINEAGEENTITYTYPE']._serialized_start = 1338
    _globals['_LINEAGEENTITYTYPE']._serialized_end = 1382
    _globals['_PROTOGETTIMESERIESBUCKETSREQUEST']._serialized_start = 65
    _globals['_PROTOGETTIMESERIESBUCKETSREQUEST']._serialized_end = 212
    _globals['_PROTOCUSTOMEXPRESSION']._serialized_start = 215
    _globals['_PROTOCUSTOMEXPRESSION']._serialized_end = 458
    _globals['_PROTOVIEW']._serialized_start = 461
    _globals['_PROTOVIEW']._serialized_end = 778
    _globals['_PROTOPOINTFILTERS']._serialized_start = 780
    _globals['_PROTOPOINTFILTERS']._serialized_end = 875
    _globals['_PROTOOPENRANGE']._serialized_start = 877
    _globals['_PROTOOPENRANGE']._serialized_end = 945
    _globals['_PROTOXAXIS']._serialized_start = 948
    _globals['_PROTOXAXIS']._serialized_end = 1185
    _globals['_XSTEPS']._serialized_start = 1187
    _globals['_XSTEPS']._serialized_end = 1195
    _globals['_XEPOCHMILLIS']._serialized_start = 1197
    _globals['_XEPOCHMILLIS']._serialized_end = 1211
    _globals['_XRELATIVETIME']._serialized_start = 1213
    _globals['_XRELATIVETIME']._serialized_end = 1228
    _globals['_XCUSTOM']._serialized_start = 1230
    _globals['_XCUSTOM']._serialized_end = 1259


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
from .... import google_rpc
from .... import neptune_pb
import sys
import typing
if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IngestCode:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IngestCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IngestCode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    OK: _IngestCode.ValueType
    'OK is returned on successful operations.'
    BATCH_CONTAINS_DEPENDENT_RUNS: _IngestCode.ValueType
    'Run create requests are not topologically sorted across batches. A single batch must not contain dependent runs.'
    PROJECT_NOT_FOUND: _IngestCode.ValueType
    'Project not found. May happen when the project is not created yet and `create_missing_project` is not set.'
    PROJECT_INVALID_NAME: _IngestCode.ValueType
    'Project name is either empty or too long.'
    RUN_NOT_FOUND: _IngestCode.ValueType
    'Run not found. May happen when the run is not yet created.'
    RUN_DUPLICATE: _IngestCode.ValueType
    'Idempotency Warning: Identical run already exists.'
    RUN_CONFLICTING: _IngestCode.ValueType
    'Run with specified `run_id` already exists, but has different creation parameters (`run_family` or `fork_point`).'
    RUN_FORK_PARENT_NOT_FOUND: _IngestCode.ValueType
    'Warning: Missing fork parent run.'
    RUN_INVALID_CREATION_PARAMETERS: _IngestCode.ValueType
    'Invalid run creation parameters. For example, experiment id is too large, etc'
    FIELD_PATH_EXCEEDS_SIZE_LIMIT: _IngestCode.ValueType
    'Field Path is too long. Maximum length is 1024 bytes (not characters)'
    FIELD_PATH_EMPTY: _IngestCode.ValueType
    'Field Path is empty.'
    FIELD_PATH_INVALID: _IngestCode.ValueType
    'Field Path is invalid for other reasons, like invalid UTF-8 encoding.'
    FIELD_PATH_NON_WRITABLE: _IngestCode.ValueType
    'Field Path is non-writable. Some special sys/ fields are read-only.'
    FIELD_TYPE_UNSUPPORTED: _IngestCode.ValueType
    'Field Type is not supported by the system.'
    FIELD_TYPE_CONFLICTING: _IngestCode.ValueType
    'Field type is different from the one that was previously logged for this series.\n    Once a field type is set, it cannot be changed.\n    '
    SERIES_POINT_DUPLICATE: _IngestCode.ValueType
    'Idempotency Warning: The exact same data point was already logged for this series.'
    SERIES_STEP_TOO_LARGE: _IngestCode.ValueType
    'Step value must be smaller than: `1_000_000_000_000`.'
    SERIES_STEP_INVALID: _IngestCode.ValueType
    'Invalid step value. Step `micro` part must be smaller than `1_000_000`.'
    SERIES_PREVIEW_STEP_NOT_AFTER_LAST_COMMITTED_STEP: _IngestCode.ValueType
    'Series preview step not after last committed step.'
    SERIES_STEP_NON_INCREASING: _IngestCode.ValueType
    "The step of a series value is lesser than the most recently logged step for this series or the step is exactly the\n    same, but the value is different (DUPLICATE_DATA_POINT doesn't apply).\n    "
    SERIES_STEP_NOT_AFTER_FORK_POINT: _IngestCode.ValueType
    'The series value must be greater than the step specified in the run Fork Point.'
    SERIES_TIMESTAMP_DECREASING: _IngestCode.ValueType
    'The timestamp of a series value is lesser than the most recently logged value. Identical timestamps are allowed.'
    FLOAT_VALUE_NAN_INF_UNSUPPORTED: _IngestCode.ValueType
    'Unsupported value type for float64 field or float64 series. Applies to Inf and NaN values.'
    DATETIME_VALUE_OUT_OF_RANGE: _IngestCode.ValueType
    'Timestamp allowed range is (1900-01-01 to 2299-12-31)'
    STRING_VALUE_EXCEEDS_SIZE_LIMIT: _IngestCode.ValueType
    'String value is too long. Maximum length is 1MiB.'
    STRING_SET_EXCEEDS_SIZE_LIMIT: _IngestCode.ValueType
    'String Set value is too long. Maximum length is 1MiB.'
    FILE_REF_EXCEEDS_SIZE_LIMIT: _IngestCode.ValueType
    'File Ref value is too long. Maximum length is 4KiB.'
    HISTOGRAM_BIN_EDGES_CONTAINS_NAN: _IngestCode.ValueType
    'Histogram must not contain `NaN` values.'
    HISTOGRAM_TOO_MANY_BINS: _IngestCode.ValueType
    'Max allowed size of bin_edges array is 513 elements, which corresponds to 512 bins.'
    HISTOGRAM_BIN_EDGES_NOT_INCREASING: _IngestCode.ValueType
    'Bins must be increasing monotonically.'
    HISTOGRAM_VALUES_LENGTH_DOESNT_MATCH_BINS: _IngestCode.ValueType
    'Histogram values and bins arrays are not matching.\n    Following must always be true: `assert len(values) == len(bins) - 1`.\n    '
    INGEST_SUSPENDED: _IngestCode.ValueType
    'Ingest is currently suspended'
    INTERNAL: _IngestCode.ValueType
    'Internal failure'

class IngestCode(_IngestCode, metaclass=_IngestCodeEnumTypeWrapper):
    """Error codes for the operations"""
OK: IngestCode.ValueType
'OK is returned on successful operations.'
BATCH_CONTAINS_DEPENDENT_RUNS: IngestCode.ValueType
'Run create requests are not topologically sorted across batches. A single batch must not contain dependent runs.'
PROJECT_NOT_FOUND: IngestCode.ValueType
'Project not found. May happen when the project is not created yet and `create_missing_project` is not set.'
PROJECT_INVALID_NAME: IngestCode.ValueType
'Project name is either empty or too long.'
RUN_NOT_FOUND: IngestCode.ValueType
'Run not found. May happen when the run is not yet created.'
RUN_DUPLICATE: IngestCode.ValueType
'Idempotency Warning: Identical run already exists.'
RUN_CONFLICTING: IngestCode.ValueType
'Run with specified `run_id` already exists, but has different creation parameters (`run_family` or `fork_point`).'
RUN_FORK_PARENT_NOT_FOUND: IngestCode.ValueType
'Warning: Missing fork parent run.'
RUN_INVALID_CREATION_PARAMETERS: IngestCode.ValueType
'Invalid run creation parameters. For example, experiment id is too large, etc'
FIELD_PATH_EXCEEDS_SIZE_LIMIT: IngestCode.ValueType
'Field Path is too long. Maximum length is 1024 bytes (not characters)'
FIELD_PATH_EMPTY: IngestCode.ValueType
'Field Path is empty.'
FIELD_PATH_INVALID: IngestCode.ValueType
'Field Path is invalid for other reasons, like invalid UTF-8 encoding.'
FIELD_PATH_NON_WRITABLE: IngestCode.ValueType
'Field Path is non-writable. Some special sys/ fields are read-only.'
FIELD_TYPE_UNSUPPORTED: IngestCode.ValueType
'Field Type is not supported by the system.'
FIELD_TYPE_CONFLICTING: IngestCode.ValueType
'Field type is different from the one that was previously logged for this series.\nOnce a field type is set, it cannot be changed.\n'
SERIES_POINT_DUPLICATE: IngestCode.ValueType
'Idempotency Warning: The exact same data point was already logged for this series.'
SERIES_STEP_TOO_LARGE: IngestCode.ValueType
'Step value must be smaller than: `1_000_000_000_000`.'
SERIES_STEP_INVALID: IngestCode.ValueType
'Invalid step value. Step `micro` part must be smaller than `1_000_000`.'
SERIES_PREVIEW_STEP_NOT_AFTER_LAST_COMMITTED_STEP: IngestCode.ValueType
'Series preview step not after last committed step.'
SERIES_STEP_NON_INCREASING: IngestCode.ValueType
"The step of a series value is lesser than the most recently logged step for this series or the step is exactly the\nsame, but the value is different (DUPLICATE_DATA_POINT doesn't apply).\n"
SERIES_STEP_NOT_AFTER_FORK_POINT: IngestCode.ValueType
'The series value must be greater than the step specified in the run Fork Point.'
SERIES_TIMESTAMP_DECREASING: IngestCode.ValueType
'The timestamp of a series value is lesser than the most recently logged value. Identical timestamps are allowed.'
FLOAT_VALUE_NAN_INF_UNSUPPORTED: IngestCode.ValueType
'Unsupported value type for float64 field or float64 series. Applies to Inf and NaN values.'
DATETIME_VALUE_OUT_OF_RANGE: IngestCode.ValueType
'Timestamp allowed range is (1900-01-01 to 2299-12-31)'
STRING_VALUE_EXCEEDS_SIZE_LIMIT: IngestCode.ValueType
'String value is too long. Maximum length is 1MiB.'
STRING_SET_EXCEEDS_SIZE_LIMIT: IngestCode.ValueType
'String Set value is too long. Maximum length is 1MiB.'
FILE_REF_EXCEEDS_SIZE_LIMIT: IngestCode.ValueType
'File Ref value is too long. Maximum length is 4KiB.'
HISTOGRAM_BIN_EDGES_CONTAINS_NAN: IngestCode.ValueType
'Histogram must not contain `NaN` values.'
HISTOGRAM_TOO_MANY_BINS: IngestCode.ValueType
'Max allowed size of bin_edges array is 513 elements, which corresponds to 512 bins.'
HISTOGRAM_BIN_EDGES_NOT_INCREASING: IngestCode.ValueType
'Bins must be increasing monotonically.'
HISTOGRAM_VALUES_LENGTH_DOESNT_MATCH_BINS: IngestCode.ValueType
'Histogram values and bins arrays are not matching.\nFollowing must always be true: `assert len(values) == len(bins) - 1`.\n'
INGEST_SUSPENDED: IngestCode.ValueType
'Ingest is currently suspended'
INTERNAL: IngestCode.ValueType
'Internal failure'
global___IngestCode = IngestCode

@typing.final
class BatchContext(google.protobuf.message.Message):
    """BatchContext"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    project: builtins.str
    'Project qualified name, e.g. "your-workspace/your-project".'
    api_key: builtins.bytes
    'API Key required used to authorize all operations withing batch.'

    def __init__(self, *, project: builtins.str=..., api_key: builtins.bytes=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['api_key', b'api_key', 'project', b'project']) -> None:
        ...
global___BatchContext = BatchContext

@typing.final
class UpdateRun(google.protobuf.message.Message):
    """Mode of update run. We currently support only Update Snapshots."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UPDATE_SNAPSHOTS_FIELD_NUMBER: builtins.int

    @property
    def update_snapshots(self) -> neptune_pb.ingest.v1.common_pb2.UpdateRunSnapshots:
        """All included fields will be aligned to the same step. In case the step is not set, it will select the
        successor of the run step, which is the highest step across individual metric leaders for this run.
        """

    def __init__(self, *, update_snapshots: neptune_pb.ingest.v1.common_pb2.UpdateRunSnapshots | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['mode', b'mode', 'update_snapshots', b'update_snapshots']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['mode', b'mode', 'update_snapshots', b'update_snapshots']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['mode', b'mode']) -> typing.Literal['update_snapshots'] | None:
        ...
global___UpdateRun = UpdateRun

@typing.final
class BatchProjectOperations(google.protobuf.message.Message):
    """BatchProjectOperations will execute operations within provided `context`. It will execute `create_runs` first and
    then `update_run_fields`. All operations within each group are unordered and may be executed simultaneously.

    Currently, Ingest API does not perform any topological sort within a single batch. Customer of this API must ensure
    that all required dependencies are met before this Batch is executed.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class UpdateRunsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str

        @property
        def value(self) -> global___UpdateRun:
            ...

        def __init__(self, *, key: builtins.str=..., value: global___UpdateRun | None=...) -> None:
            ...

        def HasField(self, field_name: typing.Literal['value', b'value']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing.Literal['key', b'key', 'value', b'value']) -> None:
            ...
    CONTEXT_FIELD_NUMBER: builtins.int
    CREATE_MISSING_PROJECT_FIELD_NUMBER: builtins.int
    CREATE_RUNS_FIELD_NUMBER: builtins.int
    UPDATE_RUNS_FIELD_NUMBER: builtins.int
    create_missing_project: builtins.bool
    "Optional. This option will instrument the server to create project if it doesn't yet exist.\n    This operation is idempotent.\n    "

    @property
    def context(self) -> global___BatchContext:
        """Required. Context of the operation: workspace, project and api key used for authorization"""

    @property
    def create_runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[neptune_pb.ingest.v1.common_pb2.Run]:
        """Optional. Creates a new Run or Forks an existing Run from the specified `parent_run` and `step`."""

    @property
    def update_runs(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___UpdateRun]:
        """Optional. Update fields for selected runs. Map key is an id of the run to be updated.
        Allows users to provide shared StepInfo, which is useful for large updates happening for the same step.
        """

    def __init__(self, *, context: global___BatchContext | None=..., create_missing_project: builtins.bool=..., create_runs: collections.abc.Iterable[neptune_pb.ingest.v1.common_pb2.Run] | None=..., update_runs: collections.abc.Mapping[builtins.str, global___UpdateRun] | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['context', b'context']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['context', b'context', 'create_missing_project', b'create_missing_project', 'create_runs', b'create_runs', 'update_runs', b'update_runs']) -> None:
        ...
global___BatchProjectOperations = BatchProjectOperations

@typing.final
class CreateRunError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRPC_CODE_FIELD_NUMBER: builtins.int
    INGEST_CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    grpc_code: google_rpc.code_pb2.Code.ValueType
    'grpc response code of the operation.'
    ingest_code: global___IngestCode.ValueType
    'error code of the operation.'
    message: builtins.str
    'error message related to the operation.'

    def __init__(self, *, grpc_code: google_rpc.code_pb2.Code.ValueType=..., ingest_code: global___IngestCode.ValueType=..., message: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['grpc_code', b'grpc_code', 'ingest_code', b'ingest_code', 'message', b'message']) -> None:
        ...
global___CreateRunError = CreateRunError

@typing.final
class CreateRunResult(google.protobuf.message.Message):
    """Run create results"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RUN_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int

    @property
    def run(self) -> neptune_pb.ingest.v1.common_pb2.Run:
        """Run successfully created by the server."""

    @property
    def error(self) -> global___CreateRunError:
        """error details."""

    def __init__(self, *, run: neptune_pb.ingest.v1.common_pb2.Run | None=..., error: global___CreateRunError | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['error', b'error', 'run', b'run', 'type', b'type']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['error', b'error', 'run', b'run', 'type', b'type']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['type', b'type']) -> typing.Literal['run', 'error'] | None:
        ...
global___CreateRunResult = CreateRunResult

@typing.final
class ResultSummary(google.protobuf.message.Message):
    """counters for the operations performed in the request, batch or run update"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FailedByGRPCCodeCounters(google.protobuf.message.Message):
        """Mapping of failed operations counts by error code."""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        GRPC_CODE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        grpc_code: google_rpc.code_pb2.Code.ValueType
        count: builtins.int

        def __init__(self, *, grpc_code: google_rpc.code_pb2.Code.ValueType=..., count: builtins.int=...) -> None:
            ...

        def ClearField(self, field_name: typing.Literal['count', b'count', 'grpc_code', b'grpc_code']) -> None:
            ...

    @typing.final
    class IngestCodeCounters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        INGEST_CODE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        ingest_code: global___IngestCode.ValueType
        count: builtins.int

        def __init__(self, *, ingest_code: global___IngestCode.ValueType=..., count: builtins.int=...) -> None:
            ...

        def ClearField(self, field_name: typing.Literal['count', b'count', 'ingest_code', b'ingest_code']) -> None:
            ...
    TOTAL_OPERATIONS_COUNT_FIELD_NUMBER: builtins.int
    SUCCESSFUL_COUNT_FIELD_NUMBER: builtins.int
    FAILED_COUNT_FIELD_NUMBER: builtins.int
    FAILED_BY_GRPC_CODE_FIELD_NUMBER: builtins.int
    FAILED_BY_INGEST_CODE_FIELD_NUMBER: builtins.int
    total_operations_count: builtins.int
    'failed_count + successful_count = total_operations_count'
    successful_count: builtins.int
    failed_count: builtins.int

    @property
    def failed_by_grpc_code(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResultSummary.FailedByGRPCCodeCounters]:
        """Failed summary details"""

    @property
    def failed_by_ingest_code(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResultSummary.IngestCodeCounters]:
        ...

    def __init__(self, *, total_operations_count: builtins.int=..., successful_count: builtins.int=..., failed_count: builtins.int=..., failed_by_grpc_code: collections.abc.Iterable[global___ResultSummary.FailedByGRPCCodeCounters] | None=..., failed_by_ingest_code: collections.abc.Iterable[global___ResultSummary.IngestCodeCounters] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['failed_by_grpc_code', b'failed_by_grpc_code', 'failed_by_ingest_code', b'failed_by_ingest_code', 'failed_count', b'failed_count', 'successful_count', b'successful_count', 'total_operations_count', b'total_operations_count']) -> None:
        ...
global___ResultSummary = ResultSummary

@typing.final
class UpdateRunError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRPC_CODE_FIELD_NUMBER: builtins.int
    INGEST_CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    FIELD_FIELD_NUMBER: builtins.int
    grpc_code: google_rpc.code_pb2.Code.ValueType
    'grpc error code of the operation.'
    ingest_code: global___IngestCode.ValueType
    'error code of the operation.'
    message: builtins.str
    'error message related to the operation.'
    field: builtins.str
    'field path is set only if a failed operation is a Field Operation.'

    def __init__(self, *, grpc_code: google_rpc.code_pb2.Code.ValueType=..., ingest_code: global___IngestCode.ValueType=..., message: builtins.str=..., field: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['field', b'field', 'grpc_code', b'grpc_code', 'ingest_code', b'ingest_code', 'message', b'message']) -> None:
        ...
global___UpdateRunError = UpdateRunError

@typing.final
class UpdateRunResults(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OPERATIONS_SUMMARY_FIELD_NUMBER: builtins.int
    UPDATE_ERRORS_FIELD_NUMBER: builtins.int

    @property
    def operations_summary(self) -> global___ResultSummary:
        ...

    @property
    def update_errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdateRunError]:
        """Detail error. If the whole batch fails due to wider conditions, per-field errors will not be listed.
        Successful field updates are not reported here, they are only counted in the `operations_summary`.
        """

    def __init__(self, *, operations_summary: global___ResultSummary | None=..., update_errors: collections.abc.Iterable[global___UpdateRunError] | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['operations_summary', b'operations_summary']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['operations_summary', b'operations_summary', 'update_errors', b'update_errors']) -> None:
        ...
global___UpdateRunResults = UpdateRunResults

@typing.final
class BatchResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class UpdateRunResultsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str

        @property
        def value(self) -> global___UpdateRunResults:
            ...

        def __init__(self, *, key: builtins.str=..., value: global___UpdateRunResults | None=...) -> None:
            ...

        def HasField(self, field_name: typing.Literal['value', b'value']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing.Literal['key', b'key', 'value', b'value']) -> None:
            ...
    GRPC_CODE_FIELD_NUMBER: builtins.int
    INGEST_CODE_FIELD_NUMBER: builtins.int
    OPERATIONS_SUMMARY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    CREATE_RUN_RESULTS_FIELD_NUMBER: builtins.int
    UPDATE_RUN_RESULTS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    grpc_code: google_rpc.code_pb2.Code.ValueType
    "Error code that applies to the whole batch. Used codes:\n    - OK: when the batch is partially successful, but there could be some operations that failed.\n      Operation-specific errors will be listed in `operation_errors`.\n    - UNAUTHENTICATED: when `api_key` is not provided.\n    - PERMISSION_DENIED: when provided `api_key` is not authorized to perform the operations on a provided context.\n    - NOT_FOUND: when `workspace` or `project` does not exist or provided`api_key` doesn't have read access to them.\n    - INVALID_ARGUMENT: when the batch is malformed to a degree that no operation can be performed.\n    - INTERNAL: when an unexpected error occurred.\n    - UNAVAILABLE: when the service is unavailable.\n    - DATA_LOSS: when the service experienced a data loss.\n    "
    ingest_code: global___IngestCode.ValueType
    project: builtins.str
    'Project associated with the batch.'
    message: builtins.str
    'Error message related to the batch failure.'

    @property
    def operations_summary(self) -> global___ResultSummary:
        """Summary of the operations performed in the batch."""

    @property
    def create_run_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateRunResult]:
        """Reports created runs in the batch. In case the user didn't set their `run_id` in the request, it will be provided
        by the server. Order of the results is preserved.
        """

    @property
    def update_run_results(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___UpdateRunResults]:
        """Run update results."""

    def __init__(self, *, grpc_code: google_rpc.code_pb2.Code.ValueType=..., ingest_code: global___IngestCode.ValueType=..., operations_summary: global___ResultSummary | None=..., project: builtins.str=..., create_run_results: collections.abc.Iterable[global___CreateRunResult] | None=..., update_run_results: collections.abc.Mapping[builtins.str, global___UpdateRunResults] | None=..., message: builtins.str=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['operations_summary', b'operations_summary']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['create_run_results', b'create_run_results', 'grpc_code', b'grpc_code', 'ingest_code', b'ingest_code', 'message', b'message', 'operations_summary', b'operations_summary', 'project', b'project', 'update_run_results', b'update_run_results']) -> None:
        ...
global___BatchResult = BatchResult

@typing.final
class IngestRequest(google.protobuf.message.Message):
    """Ingest Request is a request body for the Ingest method. It contains a list of batches of operations to be performed.
    Each Batch of operations is executed within the provided context.

    We recommend counting the number of atomic changes (points, `assign` operations) in all batches in a single
    request and keeping them between 10 thousand and 20 thousands to avoid performance issues.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BATCHES_FIELD_NUMBER: builtins.int

    @property
    def batches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchProjectOperations]:
        """Batches of operations to be performed. Each batch is executed within the provided context.

        Multiple batches may be executed together to improve Ingest performance if their operations are found to be
        independent. Batches that don't share the same Context are always considered independent and may be merged.
        """

    def __init__(self, *, batches: collections.abc.Iterable[global___BatchProjectOperations] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['batches', b'batches']) -> None:
        ...
global___IngestRequest = IngestRequest

@typing.final
class IngestResponse(google.protobuf.message.Message):
    """Ingest Response returns a list of errors for each batch of operations"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SUMMARY_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    BATCH_RESULTS_FIELD_NUMBER: builtins.int
    error_message: builtins.str
    'Error message related to the whole request. Corresponding error code is set in the response header'

    @property
    def summary(self) -> global___ResultSummary:
        """summary of the results of the operations performed in the request."""

    @property
    def batch_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchResult]:
        """Batch results. Each batch result corresponds to a single batch in the request.
        The order of the results is preserved.
        """

    def __init__(self, *, summary: global___ResultSummary | None=..., error_message: builtins.str=..., batch_results: collections.abc.Iterable[global___BatchResult] | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['summary', b'summary']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['batch_results', b'batch_results', 'error_message', b'error_message', 'summary', b'summary']) -> None:
        ...
global___IngestResponse = IngestResponse


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15google_rpc/code.proto\x12\ngoogle_rpc*\xb7\x02\n\x04Code\x12\x06\n\x02OK\x10\x00\x12\r\n\tCANCELLED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11DEADLINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0eALREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x13\n\x0fUNAUTHENTICATED\x10\x10\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13FAILED_PRECONDITION\x10\t\x12\x0b\n\x07ABORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0fBX\n\x0ecom.google.rpcB\tCodeProtoP\x01Z3google.golang.org/genproto/googleapis/rpc/code;code\xa2\x02\x03RPCb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google_rpc.code_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals['DESCRIPTOR']._options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x0ecom.google.rpcB\tCodeProtoP\x01Z3google.golang.org/genproto/googleapis/rpc/code;code\xa2\x02\x03RPC'
    _globals['_CODE']._serialized_start = 38
    _globals['_CODE']._serialized_end = 349


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SET_OPERATION:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SET_OPERATIONEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SET_OPERATION.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NOOP: _SET_OPERATION.ValueType
    ADD: _SET_OPERATION.ValueType
    REMOVE: _SET_OPERATION.ValueType

class SET_OPERATION(_SET_OPERATION, metaclass=_SET_OPERATIONEnumTypeWrapper):
    """SET_OPERATION is used to describe the operation to be performed on a set."""
NOOP: SET_OPERATION.ValueType
ADD: SET_OPERATION.ValueType
REMOVE: SET_OPERATION.ValueType
global___SET_OPERATION = SET_OPERATION

@typing.final
class Step(google.protobuf.message.Message):
    """Step is used to measure computational progress of the Run and it's used to stamp its state.
    For example, to express Step `3.5`, use `Step{whole: 3, micro: 500_000`}.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WHOLE_FIELD_NUMBER: builtins.int
    MICRO_FIELD_NUMBER: builtins.int
    whole: builtins.int
    'Whole step index.'
    micro: builtins.int
    'Fractional part of a step expressed as number of micro steps.\n    Expression `0 <= micro < 1_000_000` must be true at all times.\n    '

    def __init__(self, *, whole: builtins.int=..., micro: builtins.int=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['micro', b'micro', 'whole', b'whole']) -> None:
        ...
global___Step = Step

@typing.final
class ForkPoint(google.protobuf.message.Message):
    """ForkPoint is used to mark the parent and its last inherited state during Forking."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARENT_PROJECT_FIELD_NUMBER: builtins.int
    PARENT_RUN_ID_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    REQUESTED_PARENT_ID_FIELD_NUMBER: builtins.int
    parent_project: builtins.str
    'Optional. Parent project qualified name. If not set, it will default to the context project.'
    parent_run_id: builtins.str
    'Required. The id of the parent run within the parent project.'
    requested_parent_id: builtins.str
    'Internal. requested parent_id of the run.'

    @property
    def step(self) -> global___Step:
        """Fork Step, which is the last step that a new run will inherit from its parent.
        If not set, it will default to the last seen step of the parent run by the server at the time of forking.
        New run may start numbering steps from the next micro step after the fork step.
        """

    def __init__(self, *, parent_project: builtins.str | None=..., parent_run_id: builtins.str=..., step: global___Step | None=..., requested_parent_id: builtins.str | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_parent_project', b'_parent_project', '_requested_parent_id', b'_requested_parent_id', 'parent_project', b'parent_project', 'requested_parent_id', b'requested_parent_id', 'step', b'step']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_parent_project', b'_parent_project', '_requested_parent_id', b'_requested_parent_id', 'parent_project', b'parent_project', 'parent_run_id', b'parent_run_id', 'requested_parent_id', b'requested_parent_id', 'step', b'step']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_parent_project', b'_parent_project']) -> typing.Literal['parent_project'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_requested_parent_id', b'_requested_parent_id']) -> typing.Literal['requested_parent_id'] | None:
        ...
global___ForkPoint = ForkPoint

@typing.final
class StringSet(google.protobuf.message.Message):
    """StringSet represents a set of strings. The order of strings is irrelevant and duplicates are ignored."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUES_FIELD_NUMBER: builtins.int

    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        ...

    def __init__(self, *, values: collections.abc.Iterable[builtins.str] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['values', b'values']) -> None:
        ...
global___StringSet = StringSet

@typing.final
class FileRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    path: builtins.str
    size_bytes: builtins.int
    mime_type: builtins.str

    def __init__(self, *, path: builtins.str=..., size_bytes: builtins.int=..., mime_type: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['mime_type', b'mime_type', 'path', b'path', 'size_bytes', b'size_bytes']) -> None:
        ...
global___FileRef = FileRef

@typing.final
class Histogram(google.protobuf.message.Message):
    """Histogram represents a histogram with explicit bin edges."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Counts(google.protobuf.message.Message):
        """Counts holds the number of entries in each bin."""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        VALUES_FIELD_NUMBER: builtins.int

        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
            ...

        def __init__(self, *, values: collections.abc.Iterable[builtins.int] | None=...) -> None:
            ...

        def ClearField(self, field_name: typing.Literal['values', b'values']) -> None:
            ...

    @typing.final
    class Densities(google.protobuf.message.Message):
        """Densities holds the density (or weight) for each bin."""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        VALUES_FIELD_NUMBER: builtins.int

        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            ...

        def __init__(self, *, values: collections.abc.Iterable[builtins.float] | None=...) -> None:
            ...

        def ClearField(self, field_name: typing.Literal['values', b'values']) -> None:
            ...
    BIN_EDGES_FIELD_NUMBER: builtins.int
    COUNTS_FIELD_NUMBER: builtins.int
    DENSITIES_FIELD_NUMBER: builtins.int

    @property
    def bin_edges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """bin_edges is a sorted list of boundary values defining the histogram bins.
        Each bin is determined as follows:
          - For i in [0..(len(bin_edges) - 2)], the bin spans [bin_edges[i], bin_edges[i+1}).
          - The final bin spans [bin_edges[-2], bin_edges[-1]] (closed interval).

        bin_edges must not contain NaN values. Infinity (-∞ or +∞) is allowed at the boundaries
        to create unbounded bins. For example:
            bin_edges = [0, 1, 2, 4, 8, +∞]
          describes 5 bins:
            [0,1), [1,2), [2,4), [4,8), [8,+∞]
        """

    @property
    def counts(self) -> global___Histogram.Counts:
        """counts specifies the total number of occurrences in each bin.
        The length of counts.values must be bin_edges.length - 1.

        Example:
          counts.values = [1, 4, 3, 0, 2]
          represents:
            Range      Count   Bars
            [0,1)         1      #
            [1,2)         4      ####
            [2,4)         3      ###
            [4,8)         0
            [8,+∞]        2      ##
        """

    @property
    def densities(self) -> global___Histogram.Densities:
        """densities specifies the density for each bin.
        The length of densities.values must be bin_edges.length - 1.

        Example:
          densities.values = [0.1, 0.4, 0.15, 0.0, 0.0]
          represents:
            Range      Density   Bars
            [0,1)       0.1       #
            [1,2)       0.4       ####
            [2,4)       0.15      ##
            [4,8)       0.0
            [8,+∞]      0.0
        """

    def __init__(self, *, bin_edges: collections.abc.Iterable[builtins.float] | None=..., counts: global___Histogram.Counts | None=..., densities: global___Histogram.Densities | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['counts', b'counts', 'densities', b'densities', 'values', b'values']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['bin_edges', b'bin_edges', 'counts', b'counts', 'densities', b'densities', 'values', b'values']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['values', b'values']) -> typing.Literal['counts', 'densities'] | None:
        ...
global___Histogram = Histogram

@typing.final
class Value(google.protobuf.message.Message):
    """Value is a union of all supported types that can be used to update a field.
    Different types of operations support different subset of this field, so please refer to the documentation.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FLOAT64_FIELD_NUMBER: builtins.int
    INT64_FIELD_NUMBER: builtins.int
    BOOL_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    STRING_SET_FIELD_NUMBER: builtins.int
    FILE_REF_FIELD_NUMBER: builtins.int
    HISTOGRAM_FIELD_NUMBER: builtins.int
    float64: builtins.float
    int64: builtins.int
    bool: builtins.bool
    string: builtins.str

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        ...

    @property
    def string_set(self) -> global___StringSet:
        ...

    @property
    def file_ref(self) -> global___FileRef:
        ...

    @property
    def histogram(self) -> global___Histogram:
        ...

    def __init__(self, *, float64: builtins.float=..., int64: builtins.int=..., bool: builtins.bool=..., string: builtins.str=..., timestamp: google.protobuf.timestamp_pb2.Timestamp | None=..., string_set: global___StringSet | None=..., file_ref: global___FileRef | None=..., histogram: global___Histogram | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['bool', b'bool', 'file_ref', b'file_ref', 'float64', b'float64', 'histogram', b'histogram', 'int64', b'int64', 'string', b'string', 'string_set', b'string_set', 'timestamp', b'timestamp', 'value', b'value']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['bool', b'bool', 'file_ref', b'file_ref', 'float64', b'float64', 'histogram', b'histogram', 'int64', b'int64', 'string', b'string', 'string_set', b'string_set', 'timestamp', b'timestamp', 'value', b'value']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['value', b'value']) -> typing.Literal['float64', 'int64', 'bool', 'string', 'timestamp', 'string_set', 'file_ref', 'histogram'] | None:
        ...
global___Value = Value

@typing.final
class ModifyStringSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ValuesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: global___SET_OPERATION.ValueType

        def __init__(self, *, key: builtins.str=..., value: global___SET_OPERATION.ValueType=...) -> None:
            ...

        def ClearField(self, field_name: typing.Literal['key', b'key', 'value', b'value']) -> None:
            ...
    VALUES_FIELD_NUMBER: builtins.int

    @property
    def values(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___SET_OPERATION.ValueType]:
        ...

    def __init__(self, *, values: collections.abc.Mapping[builtins.str, global___SET_OPERATION.ValueType] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['values', b'values']) -> None:
        ...
global___ModifyStringSet = ModifyStringSet

@typing.final
class ModifySet(google.protobuf.message.Message):
    """Allows to update tag values in an incremental way."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STRING_FIELD_NUMBER: builtins.int

    @property
    def string(self) -> global___ModifyStringSet:
        ...

    def __init__(self, *, string: global___ModifyStringSet | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['string', b'string', 'type', b'type']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['string', b'string', 'type', b'type']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['type', b'type']) -> typing.Literal['string'] | None:
        ...
global___ModifySet = ModifySet

@typing.final
class Owner(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    USER_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    'Id of a person\'s account. It will appear in the "sys/owner" field.'
    service_account_id: builtins.str
    'Id of a service account used for automation.\n    When set to "myaccount", in the "sys/owner" it will appear as "myaccount@myorganization".\n    '

    def __init__(self, *, user_id: builtins.str=..., service_account_id: builtins.str=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['owner_type', b'owner_type', 'service_account_id', b'service_account_id', 'user_id', b'user_id']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['owner_type', b'owner_type', 'service_account_id', b'service_account_id', 'user_id', b'user_id']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing.Literal['owner_type', b'owner_type']) -> typing.Literal['user_id', 'service_account_id'] | None:
        ...
global___Owner = Owner

@typing.final
class OffsetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BROKER_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_OFFSET_FIELD_NUMBER: builtins.int
    broker_version: builtins.int
    'System-set. Version of configuration used by kafka for consumed topic (number of partitions, etc.). \n    Used with `message_offset` field to create robust ordering of operations\n    '
    message_offset: builtins.int
    'System-set. Message offset from kafka. Set on consumption from Kafka. \n    Used with `message_offset` field to create robust ordering of operations\n    '

    def __init__(self, *, broker_version: builtins.int | None=..., message_offset: builtins.int | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_broker_version', b'_broker_version', '_message_offset', b'_message_offset', 'broker_version', b'broker_version', 'message_offset', b'message_offset']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_broker_version', b'_broker_version', '_message_offset', b'_message_offset', 'broker_version', b'broker_version', 'message_offset', b'message_offset']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_broker_version', b'_broker_version']) -> typing.Literal['broker_version'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_message_offset', b'_message_offset']) -> typing.Literal['message_offset'] | None:
        ...
global___OffsetMetadata = OffsetMetadata

@typing.final
class Run(google.protobuf.message.Message):
    """CreateRun can be used to create a new run. This can be done in two ways:
    1. Create a new run with no inherited state. You may specify a new run family that will be
       inherited by future runs forking from this one, otherwise the new family will be selected by the server.
    2. Create a new run that inherits state from the parent run up to a specific step. You may specify
       a new run family that will be inherited by future runs forking from this one. By default, the new run
       will be in the same Family as the parent run.
    CreateRun is idempotent, as long as `fork_point` and `family` parameters are the same. In case pf conflict,
    the second operation will fail.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RUN_ID_FIELD_NUMBER: builtins.int
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    FORK_POINT_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    CREATION_TIME_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    TRACKER_FIELD_NUMBER: builtins.int
    INHERIT_CONFIGS_FIELD_NUMBER: builtins.int
    START_PROCESSING_TIME_FIELD_NUMBER: builtins.int
    OFFSET_METADATA_FIELD_NUMBER: builtins.int
    run_id: builtins.str
    'Id of the run to be created. Optional if parent context has already specified run_id. If both are set, they\n    must be equal, otherwise the operation will fail.\n    '
    experiment_id: builtins.str
    'Experiment Id to assign to this Run. If Experiment Id is already assigned to another Run, specifying it in this\n    field will move it from the previous Run, so that at most one Run in given project has a given Experiment Id.\n    Note: Experiment Id is currently exposed as "sys/name" field in the Run metadata.\n    '
    family: builtins.str
    'Specifies Family for the new run. Run Family is used to group forking runs that share common ancestry.\n    By default, the new forking run will be in the same family as the parent run.\n    '
    request_id: builtins.str
    'Optional. The request ID generated by the Neptune client, used for tracking outcome of run creation.'
    tracker: builtins.str
    'Optional. A descriptive identifier of the tracker used to create a run request (e.g neptune-scale-client-0.9),\n    value will be stored as sys/diagnostics/tracker_client\n    '
    inherit_configs: builtins.bool
    'Optional. Flag that enables copy all user-defined atoms to the child run. Defaults to false'

    @property
    def fork_point(self) -> global___ForkPoint:
        """Optional. ForkPoint is used to identify the exact point in the parent history from which the new run continues.
        If not specified, the new run will start with no inherited state.
        """

    @property
    def creation_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """User-specified creation time for the new run. This is especially useful for getting consistent relative timestamps
        for series.
        If not specified, server will use its current time instead when processing the request.
        """

    @property
    def owner(self) -> global___Owner:
        """User that is the owner of the run/experiment being created.
        If not specified, it will be set to a user named "unspecified".
        """

    @property
    def start_processing_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """System-set. This field marks the time when the Run was queued for Neptune to process.

        It may significantly differ from the `creation_time` in cases of:
        - offline mode data generation,
        - data migrations of historical runs
        """

    @property
    def offset_metadata(self) -> global___OffsetMetadata:
        """System-set. Object contains infromation to provide robust ordering of operations."""

    def __init__(self, *, run_id: builtins.str | None=..., experiment_id: builtins.str | None=..., fork_point: global___ForkPoint | None=..., family: builtins.str | None=..., creation_time: google.protobuf.timestamp_pb2.Timestamp | None=..., owner: global___Owner | None=..., request_id: builtins.str | None=..., tracker: builtins.str | None=..., inherit_configs: builtins.bool | None=..., start_processing_time: google.protobuf.timestamp_pb2.Timestamp | None=..., offset_metadata: global___OffsetMetadata | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_creation_time', b'_creation_time', '_experiment_id', b'_experiment_id', '_family', b'_family', '_fork_point', b'_fork_point', '_inherit_configs', b'_inherit_configs', '_offset_metadata', b'_offset_metadata', '_owner', b'_owner', '_request_id', b'_request_id', '_run_id', b'_run_id', '_start_processing_time', b'_start_processing_time', '_tracker', b'_tracker', 'creation_time', b'creation_time', 'experiment_id', b'experiment_id', 'family', b'family', 'fork_point', b'fork_point', 'inherit_configs', b'inherit_configs', 'offset_metadata', b'offset_metadata', 'owner', b'owner', 'request_id', b'request_id', 'run_id', b'run_id', 'start_processing_time', b'start_processing_time', 'tracker', b'tracker']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_creation_time', b'_creation_time', '_experiment_id', b'_experiment_id', '_family', b'_family', '_fork_point', b'_fork_point', '_inherit_configs', b'_inherit_configs', '_offset_metadata', b'_offset_metadata', '_owner', b'_owner', '_request_id', b'_request_id', '_run_id', b'_run_id', '_start_processing_time', b'_start_processing_time', '_tracker', b'_tracker', 'creation_time', b'creation_time', 'experiment_id', b'experiment_id', 'family', b'family', 'fork_point', b'fork_point', 'inherit_configs', b'inherit_configs', 'offset_metadata', b'offset_metadata', 'owner', b'owner', 'request_id', b'request_id', 'run_id', b'run_id', 'start_processing_time', b'start_processing_time', 'tracker', b'tracker']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_creation_time', b'_creation_time']) -> typing.Literal['creation_time'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_experiment_id', b'_experiment_id']) -> typing.Literal['experiment_id'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_family', b'_family']) -> typing.Literal['family'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_fork_point', b'_fork_point']) -> typing.Literal['fork_point'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_inherit_configs', b'_inherit_configs']) -> typing.Literal['inherit_configs'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_offset_metadata', b'_offset_metadata']) -> typing.Literal['offset_metadata'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_owner', b'_owner']) -> typing.Literal['owner'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_request_id', b'_request_id']) -> typing.Literal['request_id'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_run_id', b'_run_id']) -> typing.Literal['run_id'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_start_processing_time', b'_start_processing_time']) -> typing.Literal['start_processing_time'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_tracker', b'_tracker']) -> typing.Literal['tracker'] | None:
        ...
global___Run = Run

@typing.final
class Preview(google.protobuf.message.Message):
    """Preview allows to control whether values are preview or committed."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    COMPLETION_RATIO_FIELD_NUMBER: builtins.int
    is_preview: builtins.bool
    'This flag marks the values as preview. Preview values are not yet fully committed.\n    When this flag is set, additional completion ratio can be set to indicate the progress of the preview.\n    Previews are only supported to series (`append` field).\n    '
    completion_ratio: builtins.float
    'Completion ratio is a progress of the metric value in a bounded computation.\n    `completion_ratio` value should be set in range between `[0, 1]`.\n\n    Validation:\n    - `non-NaN` values outside this range, including `+/-Inf`, are clamped to this range.\n    - `NaN` values are be treated as `0`.\n    - missing values are treated as `0`.\n\n    Completion and commitment are separate concepts. Preview value may be fully complete, but not committed.\n    In order to commit a value, unset `is_preview` flag.\n    '

    def __init__(self, *, is_preview: builtins.bool=..., completion_ratio: builtins.float=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['completion_ratio', b'completion_ratio', 'is_preview', b'is_preview']) -> None:
        ...
global___Preview = Preview

@typing.final
class UpdateRunSnapshot(google.protobuf.message.Message):
    """Stores Snapshot information about updated fields for a single step. Only passed fields will be updated."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AssignEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str

        @property
        def value(self) -> global___Value:
            ...

        def __init__(self, *, key: builtins.str=..., value: global___Value | None=...) -> None:
            ...

        def HasField(self, field_name: typing.Literal['value', b'value']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing.Literal['key', b'key', 'value', b'value']) -> None:
            ...

    @typing.final
    class ModifySetsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str

        @property
        def value(self) -> global___ModifySet:
            ...

        def __init__(self, *, key: builtins.str=..., value: global___ModifySet | None=...) -> None:
            ...

        def HasField(self, field_name: typing.Literal['value', b'value']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing.Literal['key', b'key', 'value', b'value']) -> None:
            ...

    @typing.final
    class AppendEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str

        @property
        def value(self) -> global___Value:
            ...

        def __init__(self, *, key: builtins.str=..., value: global___Value | None=...) -> None:
            ...

        def HasField(self, field_name: typing.Literal['value', b'value']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing.Literal['key', b'key', 'value', b'value']) -> None:
            ...
    STEP_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    ASSIGN_FIELD_NUMBER: builtins.int
    MODIFY_SETS_FIELD_NUMBER: builtins.int
    APPEND_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    START_PROCESSING_TIME_FIELD_NUMBER: builtins.int
    OFFSET_METADATA_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    'Optional. The request ID generated by the Neptune client, used for tracking outcome of run update.'

    @property
    def step(self) -> global___Step:
        """Optional. Step value within the run. If not set, it will default to next full step of the run
        (highest step across step values).
        """

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp field common to all included operations"""

    @property
    def preview(self) -> global___Preview:
        """Preview allows to control whether values are preview or committed.
        When not specified, the values are considered committed.
        """

    @property
    def assign(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Value]:
        """Assigns values for fields. Fields `field_path` is used as a key. Example:
        ```
        {assign: {
          "parameters/learning_rate":  {float64: 0.01},
          "parameters/optimizer":      {string: "sgd"}}}
        ```
        Note: when using a StringSet value, this action will override the whole Set with the new values.
              If you want to add or remove tags individually, use `modify_set.string` instead.
        """

    @property
    def modify_sets(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___ModifySet]:
        """Modify string sets with incremental changes. For example:
        ```
        {modify_sets: {
             "sys/tags": {
               "string": {
                 values: {
                   "new_tag1":  ADD,
                   "prev_tag1": REMOVE,
                   "new_tag2":  ADD}}}}
        ```
        """

    @property
    def append(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Value]:
        """Appends values for Series fields. Fields `field_path` is used as a key. Example:
        ```
        {assign: {
          "metrics/recall":    {float64: 0.6},
          "metrics/precision": {float64: 0.72}}}
        ```
        Note: when using a StringSet value, this action will override the whole Set with the new values.
              If you want to add or remove tags individually, use `modify_set.string` instead.
        """

    @property
    def start_processing_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """System-set. This field marks the time when the snapshot was queued for Neptune to process.

        This timestamp may significantly differ from the `timestamp` in cases of:
        - offline mode data generation,
        - data migrations of historical runs,
        - slow metric computation
        """

    @property
    def offset_metadata(self) -> global___OffsetMetadata:
        """System-set. Object contains infromation to provide robust ordering of operations."""

    def __init__(self, *, step: global___Step | None=..., timestamp: google.protobuf.timestamp_pb2.Timestamp | None=..., preview: global___Preview | None=..., assign: collections.abc.Mapping[builtins.str, global___Value] | None=..., modify_sets: collections.abc.Mapping[builtins.str, global___ModifySet] | None=..., append: collections.abc.Mapping[builtins.str, global___Value] | None=..., request_id: builtins.str | None=..., start_processing_time: google.protobuf.timestamp_pb2.Timestamp | None=..., offset_metadata: global___OffsetMetadata | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_offset_metadata', b'_offset_metadata', '_preview', b'_preview', '_request_id', b'_request_id', '_start_processing_time', b'_start_processing_time', '_step', b'_step', '_timestamp', b'_timestamp', 'offset_metadata', b'offset_metadata', 'preview', b'preview', 'request_id', b'request_id', 'start_processing_time', b'start_processing_time', 'step', b'step', 'timestamp', b'timestamp']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_offset_metadata', b'_offset_metadata', '_preview', b'_preview', '_request_id', b'_request_id', '_start_processing_time', b'_start_processing_time', '_step', b'_step', '_timestamp', b'_timestamp', 'append', b'append', 'assign', b'assign', 'modify_sets', b'modify_sets', 'offset_metadata', b'offset_metadata', 'preview', b'preview', 'request_id', b'request_id', 'start_processing_time', b'start_processing_time', 'step', b'step', 'timestamp', b'timestamp']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_offset_metadata', b'_offset_metadata']) -> typing.Literal['offset_metadata'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_preview', b'_preview']) -> typing.Literal['preview'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_request_id', b'_request_id']) -> typing.Literal['request_id'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_start_processing_time', b'_start_processing_time']) -> typing.Literal['start_processing_time'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_step', b'_step']) -> typing.Literal['step'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_timestamp', b'_timestamp']) -> typing.Literal['timestamp'] | None:
        ...
global___UpdateRunSnapshot = UpdateRunSnapshot

@typing.final
class UpdateRunSnapshots(google.protobuf.message.Message):
    """UpdateSnapshots updates fields for a given step. Used to update current state of the run in a single step.
    It's especially useful when user updates a large number of disparate fields in a single or few steps.
    All fields that were seen in a single snapshot will be aligned to the same step. In case the step is not set,
    it will select the successor of the highest step across applicable individual metric leaders for this run.
    Example:
    ```
    [{step: {whole: 1},
     timestamp: "2020-01-01T00:00:00Z",
     assign: {
       "parameters/learning_rate":  {float64: 0.001},
       "parameters/param1":         {float64: 0.1}},
     append: {
       "metrics/precision":         {float64: 0.72}}},
    {step: {whole: 2},
     timestamp: "2020-01-01T00:00:00Z",
     append: {
       "metrics/recall":     {float64: 0.6},
       "metrics/precision":  {float64: 0.74}}}]

    ```
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SNAPSHOTS_FIELD_NUMBER: builtins.int

    @property
    def snapshots(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdateRunSnapshot]:
        ...

    def __init__(self, *, snapshots: collections.abc.Iterable[global___UpdateRunSnapshot] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['snapshots', b'snapshots']) -> None:
        ...
global___UpdateRunSnapshots = UpdateRunSnapshots


#
# Copyright (c) 2025, Neptune Labs Sp. z o.o.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from enum import Enum


class AttributeTypeDTO(str, Enum):
    BOOL = "bool"
    COMPLEX = "complex"
    DATETIME = "datetime"
    EXPERIMENTSTATE = "experimentState"
    FILEREF = "fileRef"
    FILEREFSERIES = "fileRefSeries"
    FLOAT = "float"
    FLOATSERIES = "floatSeries"
    GITREF = "gitRef"
    HISTOGRAMSERIES = "histogramSeries"
    INT = "int"
    STRING = "string"
    STRINGSERIES = "stringSeries"
    STRINGSET = "stringSet"

    def __str__(self) -> str:
        return str(self.value)



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_sym_db = _symbol_database.Default()
from .....neptune_pb.ingest.v1 import common_pb2 as neptune__pb_dot_ingest_dot_v1_dot_common__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%neptune_pb/ingest/v1/pub/ingest.proto\x12\x15neptune.ingest.v1.pub\x1a!neptune_pb/ingest/v1/common.proto"\xbf\x02\n\x0cRunOperation\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\t\x12#\n\x16create_missing_project\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12(\n\x06create\x18\x06 \x01(\x0b2\x16.neptune.ingest.v1.RunH\x00\x126\n\x06update\x18\x07 \x01(\x0b2$.neptune.ingest.v1.UpdateRunSnapshotH\x00\x12=\n\x0cupdate_batch\x18\x08 \x01(\x0b2%.neptune.ingest.v1.UpdateRunSnapshotsH\x00\x12\x14\n\x07api_key\x18\x0c \x01(\x0cH\x02\x88\x01\x01B\x0b\n\toperationB\x19\n\x17_create_missing_projectB\n\n\x08_api_keyB<\n(ml.neptune.leaderboard.api.ingest.v1.pubB\x0eIngestPubProtoP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neptune_pb.ingest.v1.pub.ingest_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals['DESCRIPTOR']._options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n(ml.neptune.leaderboard.api.ingest.v1.pubB\x0eIngestPubProtoP\x01'
    _globals['_RUNOPERATION']._serialized_start = 100
    _globals['_RUNOPERATION']._serialized_end = 419